.. _tools:

Tools
=======

Included in this package is a few “goodies”:

* `PyLadies Meetup Script`_: A script to help you interact with Meetup.com.  Requires your credentials.  Useful for when developing your local chapter’s location information on ``pyladies.com/locations`` as it requires your Meetup ID and there is no easy way to find it otherwise.
.. TODO: need to create this script!
* `If Meet Then Tweet`_: A script that allows you to tweet new members of your Meetup group.  It will only tweet those that made their Twitter handle public.  Set to run once a day.

Note that these are *separate* packages with their own maintainer, license, project URLs, contribution how-tos, etc.

Have more PyLadies-specific tools and goodies that you use or created?  Submit a `pull request`_!

.. _PyLadies Meetup Script: https://github.com/pyladies/meetupscript
.. _If Meet Then Tweet: https://github.com/econchick/IfMeetThenTweet
.. _pull request: https://github.com/pyladies/pyladies-kit/pulls